==> jmb.tools-0.3.1.tar.gz: jmb.tools-0.3.1/jmb/tools/test/enabled.py <==
import re
import socket

import pyquery
import click
import requests
from requests.auth import HTTPBasicAuth
from ..conf import nginx

@click.command('enabled')
@click.option('--ssl/--no-ssl', is_flag=True, help="Test/Don't test https", default=True)
@click.option('--user', '-u', help="The user for basic authentication")
@click.option('--ip', help="the ip to be used when checking if server_name points correctly")
@click.option('--password', '-p', help="The pass for basic authentication")
@click.option('--ns', help="The nameserver to use")
@click.option('--response', '-r', is_flag=True, default=False, help="Test the response")
@click.option('--classes', '-c', is_flag=True, default=False, help="Test the classes of server_names")
@click.option('--verbose', '-v', is_flag=True, help="Be verbose and declare the hostname you're testing")
@click.option('--follow-redirects', '-f', is_flag=True, default=False, help="Follow all redirects to get the real page")
@click.argument('conf', nargs=-1)
def test_resolve(ssl, user, password, verbose, follow_redirects, conf, ip, ns, classes, response):
    "Test conf files: server names correctness"

    if ip and re.search('[a-z]', ip):
        ip = socket.gethostbyname(ip)

    ctx = click.get_current_context().parent.parent
    for filename in conf:
        if ctx.verbose:
            click.secho(filename, fg='magenta')
        pc = nginx.ParseConf(filename)
        for srv in pc.servers:

            if classes:
                srv.test_all_name_classes(ip=ip, nameserver=ns)

            if response:
                srv.test_all_name_responses(
                    ip=ip, nameserver=ns, verbose=ctx.verbose, follow_redirects=follow_redirects)

            else:
                srv.test_all_names(ip=ip, nameserver=ns)


def test_conf(filename, verbose=False, ip=None, nameserver=None):
    ctx = click.get_current_context().parent.parent
    if ctx.verbose:
        click.secho(filename, fg='magenta')
    pc = nginx.ParseConf(filename)
    for srv in pc.servers:
        srv.test_all_names(ip, nameserver=nameserver)

def test_classes(filename, verbose=False, ip=None, nameserver=None):
        srv.test_all_names(ip, nameserver=nameserver)

==> jmb.tools-0.3.2.tar.gz: jmb.tools-0.3.2/jmb/tools/test/enabled.py <==
import re
import socket

import pyquery
import click
import requests
from requests.auth import HTTPBasicAuth
from ..conf import nginx, read

@click.command('enabled')
@click.option('--ssl', is_flag=True, help="Test https even if not present in this nginx conf", default=False)
@click.option('--user', '-u', help="The user for basic authentication")
@click.option('--ip', help="the ip to be used when checking if server_name points correctly")
@click.option('--password', '-p', help="The pass for basic authentication")
@click.option('--ns', help="The nameserver to use")
@click.option('--response', '-r', is_flag=True, default=False, help="Test the response")
@click.option('--classes', '-c', is_flag=True, default=False, help="Test the classes of server_names")
@click.option('--verbose', '-v', is_flag=True, help="Be verbose and declare the hostname you're testing")
@click.option('--follow-redirects', '-f', is_flag=True, default=False, help="Follow all redirects to get the real page")
@click.argument('conf', nargs=-1)
def test_resolve(ssl, user, password, verbose, follow_redirects, conf, ip, ns, classes, response):
    "Test conf files: server names correctness"

    if ip and re.search('[a-z]', ip):
        ip = socket.gethostbyname(ip)
    if not ip:
        ip = read.get_ip()

    ctx = click.get_current_context().parent.parent
    for filename in conf:
        if ctx.verbose:
            click.secho(filename, fg='magenta')
        pc = nginx.ParseConf(filename)
        for srv in pc.servers:

            if classes:
                srv.test_all_name_classes(ip=ip, nameserver=ns)

            if response:
                srv.test_all_name_responses(
                    ip=ip, nameserver=ns, verbose=ctx.verbose, follow_redirects=follow_redirects, ssl=ssl)

            else:
                srv.test_all_names(ip=ip, nameserver=ns)


def test_conf(filename, verbose=False, ip=None, nameserver=None):
    ctx = click.get_current_context().parent.parent
    if ctx.verbose:
        click.secho(filename, fg='magenta')
    pc = nginx.ParseConf(filename)
    for srv in pc.servers:
        srv.test_all_names(ip, nameserver=nameserver)

def test_classes(filename, verbose=False, ip=None, nameserver=None):
        srv.test_all_names(ip, nameserver=nameserver)
